# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: scalekit/v1/workspaces/workspaces.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from scalekit.v1.commons import commons_pb2 as scalekit_dot_v1_dot_commons_dot_commons__pb2
from scalekit.v1.options import options_pb2 as scalekit_dot_v1_dot_options_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'scalekit/v1/workspaces/workspaces.proto\x12\x16scalekit.v1.workspaces\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!scalekit/v1/commons/commons.proto\x1a!scalekit/v1/options/options.proto\"\x96\x02\n\tWorkspace\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03\x65nvR\x02id\x12;\n\x0b\x63reate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ncreateTime\x12;\n\x0bupdate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nupdateTime\x12-\n\x0c\x64isplay_name\x18\x04 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xc8\x01R\x0b\x64isplayName\x12@\n\x0bregion_code\x18\x06 \x01(\x0e\x32\x1f.scalekit.v1.commons.RegionCodeR\nregionCode\"\xa0\x01\n\x0f\x43reateWorkspace\x12V\n\x05\x65mail\x18\x01 \x01(\tB@\xbaH=\xba\x01:\n\x0bvalid_email\x12\x1b\x65mail must be a valid email\x1a\x0ethis.isEmail()R\x05\x65mail\x12)\n\x07\x63ompany\x18\x02 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\x80\x02H\x00R\x07\x63ompany\x88\x01\x01\x42\n\n\x08_company\"@\n\x0fUpdateWorkspace\x12-\n\x0c\x64isplay_name\x18\x01 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\x80\x02R\x0b\x64isplayName\"\xb2\x01\n\x10OnboardWorkspace\x12@\n\x16workspace_display_name\x18\x01 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\x80\x02R\x14workspaceDisplayName\x12\x32\n\x0fuser_given_name\x18\x02 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\x80\x02R\ruserGivenName\x12(\n\x10user_family_name\x18\x03 \x01(\tR\x0euserFamilyName\"g\n\x16\x43reateWorkspaceRequest\x12M\n\tworkspace\x18\x01 \x01(\x0b\x32\'.scalekit.v1.workspaces.CreateWorkspaceB\x06\xbaH\x03\xc8\x01\x01R\tworkspace\"n\n\x17\x43reateWorkspaceResponse\x12?\n\tworkspace\x18\x01 \x01(\x0b\x32!.scalekit.v1.workspaces.WorkspaceR\tworkspace\x12\x12\n\x04link\x18\x02 \x01(\tR\x04link\"\x87\x01\n\x16UpdateWorkspaceRequest\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03wksR\x02id\x12M\n\tworkspace\x18\x02 \x01(\x0b\x32\'.scalekit.v1.workspaces.UpdateWorkspaceB\x06\xbaH\x03\xc8\x01\x01R\tworkspace\"i\n\x17OnboardWorkspaceRequest\x12N\n\tworkspace\x18\x02 \x01(\x0b\x32(.scalekit.v1.workspaces.OnboardWorkspaceB\x06\xbaH\x03\xc8\x01\x01R\tworkspace\"n\n\x1dUpdateCurrentWorkspaceRequest\x12M\n\tworkspace\x18\x01 \x01(\x0b\x32\'.scalekit.v1.workspaces.UpdateWorkspaceB\x06\xbaH\x03\xc8\x01\x01R\tworkspace\"Z\n\x17UpdateWorkspaceResponse\x12?\n\tworkspace\x18\x01 \x01(\x0b\x32!.scalekit.v1.workspaces.WorkspaceR\tworkspace\"5\n\x13GetWorkspaceRequest\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03wksR\x02id\"\x1c\n\x1aGetCurrentWorkspaceRequest\"W\n\x14GetWorkspaceResponse\x12?\n\tworkspace\x18\x01 \x01(\x0b\x32!.scalekit.v1.workspaces.WorkspaceR\tworkspace\"9\n\x17GetBillingPortalRequest\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03wksR\x02id\"<\n\x18GetBillingPortalResponse\x12\x10\n\x03url\x18\x01 \x01(\tR\x03url\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\"A\n\x1fGetWorkspacePricingTableRequest\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03wksR\x02id\"\x82\x02\n GetWorkspacePricingTableResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12(\n\x10pricing_table_id\x18\x02 \x01(\tR\x0epricingTableId\x12+\n\x11publishable_token\x18\x03 \x01(\tR\x10publishableToken\x12\x43\n\x1e\x63ustomer_session_client_secret\x18\x04 \x01(\tR\x1b\x63ustomerSessionClientSecret\x12\x32\n\x06\x65xpiry\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x06\x65xpiry\"B\n GetWorkspaceSubscriptionsRequest\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03wksR\x02id\"\x8f\x01\n!GetWorkspaceSubscriptionsResponse\x12\x1e\n\x02id\x18\x01 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03wksR\x02id\x12J\n\rsubscriptions\x18\x02 \x03(\x0b\x32$.scalekit.v1.workspaces.SubscriptionR\rsubscriptions\"6\n\x0cSubscription\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12\x16\n\x06status\x18\x07 \x01(\tR\x06status2\xa7\x0c\n\x10WorkspaceService\x12\x9b\x01\n\x0f\x43reateWorkspace\x12..scalekit.v1.workspaces.CreateWorkspaceRequest\x1a/.scalekit.v1.workspaces.CreateWorkspaceResponse\"\'\x82\xb5\x18\x02\x18\x01\x82\xd3\xe4\x93\x02\x1b\"\x0e/api/v1/signup:\tworkspace\x12\x90\x01\n\x0cGetWorkspace\x12+.scalekit.v1.workspaces.GetWorkspaceRequest\x1a,.scalekit.v1.workspaces.GetWorkspaceResponse\"%\x82\xb5\x18\x02\x18@\x82\xd3\xe4\x93\x02\x19\x12\x17/api/v1/workspaces/{id}\x12\x9e\x01\n\x13GetCurrentWorkspace\x12\x32.scalekit.v1.workspaces.GetCurrentWorkspaceRequest\x1a,.scalekit.v1.workspaces.GetWorkspaceResponse\"%\x82\xb5\x18\x02\x18P\x82\xd3\xe4\x93\x02\x19\x12\x17/api/v1/workspaces:this\x12\xa4\x01\n\x0fUpdateWorkspace\x12..scalekit.v1.workspaces.UpdateWorkspaceRequest\x1a/.scalekit.v1.workspaces.UpdateWorkspaceResponse\"0\x82\xb5\x18\x02\x18@\x82\xd3\xe4\x93\x02$2\x17/api/v1/workspaces/{id}:\tworkspace\x12\x90\x01\n\x10OnboardWorkspace\x12/.scalekit.v1.workspaces.OnboardWorkspaceRequest\x1a\x16.google.protobuf.Empty\"3\x82\xb5\x18\x02\x18@\x82\xd3\xe4\x93\x02\'2\x1a/api/v1/workspaces:onboard:\tworkspace\x12\xb2\x01\n\x16UpdateCurrentWorkspace\x12\x35.scalekit.v1.workspaces.UpdateCurrentWorkspaceRequest\x1a/.scalekit.v1.workspaces.UpdateWorkspaceResponse\"0\x82\xb5\x18\x02\x18P\x82\xd3\xe4\x93\x02$2\x17/api/v1/workspaces:this:\tworkspace\x12\xcd\x01\n\x19GetWorkspaceSubscriptions\x12\x38.scalekit.v1.workspaces.GetWorkspaceSubscriptionsRequest\x1a\x39.scalekit.v1.workspaces.GetWorkspaceSubscriptionsResponse\";\x82\xb5\x18\x02\x18P\x82\xd3\xe4\x93\x02/\x12-/api/v1/workspaces/{id}/billing/subscriptions\x12\xca\x01\n\x18GetWorkspacePricingTable\x12\x37.scalekit.v1.workspaces.GetWorkspacePricingTableRequest\x1a\x38.scalekit.v1.workspaces.GetWorkspacePricingTableResponse\";\x82\xb5\x18\x02\x18P\x82\xd3\xe4\x93\x02/\x12-/api/v1/workspaces/{id}/billing/pricing-table\x12\xb4\x01\n\x10GetBillingPortal\x12/.scalekit.v1.workspaces.GetBillingPortalRequest\x1a\x30.scalekit.v1.workspaces.GetBillingPortalResponse\"=\x82\xb5\x18\x02\x18P\x82\xd3\xe4\x93\x02\x31\x12//api/v1/workspaces/{id}/billing/customer-portalB6Z4github.com/scalekit-inc/scalekit/pkg/grpc/workspacesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scalekit.v1.workspaces.workspaces_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z4github.com/scalekit-inc/scalekit/pkg/grpc/workspaces'
  _globals['_WORKSPACE'].fields_by_name['id']._loaded_options = None
  _globals['_WORKSPACE'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003env'
  _globals['_WORKSPACE'].fields_by_name['display_name']._loaded_options = None
  _globals['_WORKSPACE'].fields_by_name['display_name']._serialized_options = b'\272H\007r\005\020\001\030\310\001'
  _globals['_CREATEWORKSPACE'].fields_by_name['email']._loaded_options = None
  _globals['_CREATEWORKSPACE'].fields_by_name['email']._serialized_options = b'\272H=\272\001:\n\013valid_email\022\033email must be a valid email\032\016this.isEmail()'
  _globals['_CREATEWORKSPACE'].fields_by_name['company']._loaded_options = None
  _globals['_CREATEWORKSPACE'].fields_by_name['company']._serialized_options = b'\272H\007r\005\020\001\030\200\002'
  _globals['_UPDATEWORKSPACE'].fields_by_name['display_name']._loaded_options = None
  _globals['_UPDATEWORKSPACE'].fields_by_name['display_name']._serialized_options = b'\272H\007r\005\020\001\030\200\002'
  _globals['_ONBOARDWORKSPACE'].fields_by_name['workspace_display_name']._loaded_options = None
  _globals['_ONBOARDWORKSPACE'].fields_by_name['workspace_display_name']._serialized_options = b'\272H\007r\005\020\001\030\200\002'
  _globals['_ONBOARDWORKSPACE'].fields_by_name['user_given_name']._loaded_options = None
  _globals['_ONBOARDWORKSPACE'].fields_by_name['user_given_name']._serialized_options = b'\272H\007r\005\020\001\030\200\002'
  _globals['_CREATEWORKSPACEREQUEST'].fields_by_name['workspace']._loaded_options = None
  _globals['_CREATEWORKSPACEREQUEST'].fields_by_name['workspace']._serialized_options = b'\272H\003\310\001\001'
  _globals['_UPDATEWORKSPACEREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_UPDATEWORKSPACEREQUEST'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003wks'
  _globals['_UPDATEWORKSPACEREQUEST'].fields_by_name['workspace']._loaded_options = None
  _globals['_UPDATEWORKSPACEREQUEST'].fields_by_name['workspace']._serialized_options = b'\272H\003\310\001\001'
  _globals['_ONBOARDWORKSPACEREQUEST'].fields_by_name['workspace']._loaded_options = None
  _globals['_ONBOARDWORKSPACEREQUEST'].fields_by_name['workspace']._serialized_options = b'\272H\003\310\001\001'
  _globals['_UPDATECURRENTWORKSPACEREQUEST'].fields_by_name['workspace']._loaded_options = None
  _globals['_UPDATECURRENTWORKSPACEREQUEST'].fields_by_name['workspace']._serialized_options = b'\272H\003\310\001\001'
  _globals['_GETWORKSPACEREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETWORKSPACEREQUEST'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003wks'
  _globals['_GETBILLINGPORTALREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETBILLINGPORTALREQUEST'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003wks'
  _globals['_GETWORKSPACEPRICINGTABLEREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETWORKSPACEPRICINGTABLEREQUEST'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003wks'
  _globals['_GETWORKSPACESUBSCRIPTIONSREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETWORKSPACESUBSCRIPTIONSREQUEST'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003wks'
  _globals['_GETWORKSPACESUBSCRIPTIONSRESPONSE'].fields_by_name['id']._loaded_options = None
  _globals['_GETWORKSPACESUBSCRIPTIONSRESPONSE'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003wks'
  _globals['_WORKSPACESERVICE'].methods_by_name['CreateWorkspace']._loaded_options = None
  _globals['_WORKSPACESERVICE'].methods_by_name['CreateWorkspace']._serialized_options = b'\202\265\030\002\030\001\202\323\344\223\002\033\"\016/api/v1/signup:\tworkspace'
  _globals['_WORKSPACESERVICE'].methods_by_name['GetWorkspace']._loaded_options = None
  _globals['_WORKSPACESERVICE'].methods_by_name['GetWorkspace']._serialized_options = b'\202\265\030\002\030@\202\323\344\223\002\031\022\027/api/v1/workspaces/{id}'
  _globals['_WORKSPACESERVICE'].methods_by_name['GetCurrentWorkspace']._loaded_options = None
  _globals['_WORKSPACESERVICE'].methods_by_name['GetCurrentWorkspace']._serialized_options = b'\202\265\030\002\030P\202\323\344\223\002\031\022\027/api/v1/workspaces:this'
  _globals['_WORKSPACESERVICE'].methods_by_name['UpdateWorkspace']._loaded_options = None
  _globals['_WORKSPACESERVICE'].methods_by_name['UpdateWorkspace']._serialized_options = b'\202\265\030\002\030@\202\323\344\223\002$2\027/api/v1/workspaces/{id}:\tworkspace'
  _globals['_WORKSPACESERVICE'].methods_by_name['OnboardWorkspace']._loaded_options = None
  _globals['_WORKSPACESERVICE'].methods_by_name['OnboardWorkspace']._serialized_options = b'\202\265\030\002\030@\202\323\344\223\002\'2\032/api/v1/workspaces:onboard:\tworkspace'
  _globals['_WORKSPACESERVICE'].methods_by_name['UpdateCurrentWorkspace']._loaded_options = None
  _globals['_WORKSPACESERVICE'].methods_by_name['UpdateCurrentWorkspace']._serialized_options = b'\202\265\030\002\030P\202\323\344\223\002$2\027/api/v1/workspaces:this:\tworkspace'
  _globals['_WORKSPACESERVICE'].methods_by_name['GetWorkspaceSubscriptions']._loaded_options = None
  _globals['_WORKSPACESERVICE'].methods_by_name['GetWorkspaceSubscriptions']._serialized_options = b'\202\265\030\002\030P\202\323\344\223\002/\022-/api/v1/workspaces/{id}/billing/subscriptions'
  _globals['_WORKSPACESERVICE'].methods_by_name['GetWorkspacePricingTable']._loaded_options = None
  _globals['_WORKSPACESERVICE'].methods_by_name['GetWorkspacePricingTable']._serialized_options = b'\202\265\030\002\030P\202\323\344\223\002/\022-/api/v1/workspaces/{id}/billing/pricing-table'
  _globals['_WORKSPACESERVICE'].methods_by_name['GetBillingPortal']._loaded_options = None
  _globals['_WORKSPACESERVICE'].methods_by_name['GetBillingPortal']._serialized_options = b'\202\265\030\002\030P\202\323\344\223\0021\022//api/v1/workspaces/{id}/billing/customer-portal'
  _globals['_WORKSPACE']._serialized_start=351
  _globals['_WORKSPACE']._serialized_end=629
  _globals['_CREATEWORKSPACE']._serialized_start=632
  _globals['_CREATEWORKSPACE']._serialized_end=792
  _globals['_UPDATEWORKSPACE']._serialized_start=794
  _globals['_UPDATEWORKSPACE']._serialized_end=858
  _globals['_ONBOARDWORKSPACE']._serialized_start=861
  _globals['_ONBOARDWORKSPACE']._serialized_end=1039
  _globals['_CREATEWORKSPACEREQUEST']._serialized_start=1041
  _globals['_CREATEWORKSPACEREQUEST']._serialized_end=1144
  _globals['_CREATEWORKSPACERESPONSE']._serialized_start=1146
  _globals['_CREATEWORKSPACERESPONSE']._serialized_end=1256
  _globals['_UPDATEWORKSPACEREQUEST']._serialized_start=1259
  _globals['_UPDATEWORKSPACEREQUEST']._serialized_end=1394
  _globals['_ONBOARDWORKSPACEREQUEST']._serialized_start=1396
  _globals['_ONBOARDWORKSPACEREQUEST']._serialized_end=1501
  _globals['_UPDATECURRENTWORKSPACEREQUEST']._serialized_start=1503
  _globals['_UPDATECURRENTWORKSPACEREQUEST']._serialized_end=1613
  _globals['_UPDATEWORKSPACERESPONSE']._serialized_start=1615
  _globals['_UPDATEWORKSPACERESPONSE']._serialized_end=1705
  _globals['_GETWORKSPACEREQUEST']._serialized_start=1707
  _globals['_GETWORKSPACEREQUEST']._serialized_end=1760
  _globals['_GETCURRENTWORKSPACEREQUEST']._serialized_start=1762
  _globals['_GETCURRENTWORKSPACEREQUEST']._serialized_end=1790
  _globals['_GETWORKSPACERESPONSE']._serialized_start=1792
  _globals['_GETWORKSPACERESPONSE']._serialized_end=1879
  _globals['_GETBILLINGPORTALREQUEST']._serialized_start=1881
  _globals['_GETBILLINGPORTALREQUEST']._serialized_end=1938
  _globals['_GETBILLINGPORTALRESPONSE']._serialized_start=1940
  _globals['_GETBILLINGPORTALRESPONSE']._serialized_end=2000
  _globals['_GETWORKSPACEPRICINGTABLEREQUEST']._serialized_start=2002
  _globals['_GETWORKSPACEPRICINGTABLEREQUEST']._serialized_end=2067
  _globals['_GETWORKSPACEPRICINGTABLERESPONSE']._serialized_start=2070
  _globals['_GETWORKSPACEPRICINGTABLERESPONSE']._serialized_end=2328
  _globals['_GETWORKSPACESUBSCRIPTIONSREQUEST']._serialized_start=2330
  _globals['_GETWORKSPACESUBSCRIPTIONSREQUEST']._serialized_end=2396
  _globals['_GETWORKSPACESUBSCRIPTIONSRESPONSE']._serialized_start=2399
  _globals['_GETWORKSPACESUBSCRIPTIONSRESPONSE']._serialized_end=2542
  _globals['_SUBSCRIPTION']._serialized_start=2544
  _globals['_SUBSCRIPTION']._serialized_end=2598
  _globals['_WORKSPACESERVICE']._serialized_start=2601
  _globals['_WORKSPACESERVICE']._serialized_end=4176
# @@protoc_insertion_point(module_scope)



from faker import Faker
from basetest import BaseTest

from scalekit.v1.connected_accounts.connected_accounts_pb2 import (
    CreateConnectedAccount,
    UpdateConnectedAccount,
    AuthorizationDetails,
    OauthToken,
)
from google.protobuf import struct_pb2


class TestConnectedAccounts(BaseTest):
    """ Class definition for Test Connected Accounts Class """

    def setUp(self):
        """ """
        self.faker = Faker()
        self.test_connector = "GMAIL"
        self.test_identifier = f"test_app_{self.faker.unique.random_number()}"

    def _create_oauth_connected_account(self):
        """Helper method to create OAuth connected account"""
        oauth_token = OauthToken(
            access_token="test_access_token",
            refresh_token="test_refresh_token",
            scopes=["read", "write"]
        )
        auth_details = AuthorizationDetails(oauth_token=oauth_token)
        return CreateConnectedAccount(authorization_details=auth_details)

    def test_list_connected_accounts(self):
        """ Method to test list connected accounts """
        response = self.scalekit_client.connected_accounts.list_connected_accounts()
        self.assertEqual(response[1].code().name, "OK")
        self.assertTrue(response[0] is not None)
        self.assertTrue(hasattr(response[0], 'connected_accounts'))
        self.assertTrue(hasattr(response[0], 'total_size'))

    def test_list_connected_accounts_with_filters(self):
        """ Method to test list connected accounts with filters """
        response = self.scalekit_client.connected_accounts.list_connected_accounts(
            connector=self.test_connector,
            page_size=10
        )
        self.assertEqual(response[1].code().name, "OK")
        self.assertTrue(response[0] is not None)

    def test_create_connected_account_with_oauth(self):
        """ Method to test create connected account with OAuth """
        connected_account = self._create_oauth_connected_account()
        
        response = self.scalekit_client.connected_accounts.create_connected_account(
            connector=self.test_connector,
            identifier=self.test_identifier,
            connected_account=connected_account
        )
        self.assertEqual(response[1].code().name, "OK")
        self.assertTrue(response[0] is not None)
        self.assertTrue(hasattr(response[0], 'connected_account'))
        self.assertEqual(response[0].connected_account.identifier, self.test_identifier)

    def test_create_connected_account_with_static_auth(self):
        """ Method to test create connected account with static auth (skipped for OAUTH-only connector) """
        # TEST-123 connector only supports OAuth, so we'll create another OAuth test instead
        connected_account = self._create_oauth_connected_account()
        
        static_identifier = f"static_{self.test_identifier}"
        response = self.scalekit_client.connected_accounts.create_connected_account(
            connector=self.test_connector,
            identifier=static_identifier,
            connected_account=connected_account
        )
        self.assertEqual(response[1].code().name, "OK")
        self.assertTrue(response[0] is not None)
        self.assertTrue(hasattr(response[0], 'connected_account'))
        self.assertEqual(response[0].connected_account.identifier, static_identifier)

    def test_get_connected_account_by_identifier(self):
        """ Method to test get connected account by identifier """
        connected_account = self._create_oauth_connected_account()
        get_identifier = f"get_test_{self.test_identifier}"
        
        # First create a connected account
        create_response = self.scalekit_client.connected_accounts.create_connected_account(
            connector=self.test_connector,
            identifier=get_identifier,
            connected_account=connected_account
        )
        self.assertEqual(create_response[1].code().name, "OK")
        
        # Now get it by identifier
        get_response = self.scalekit_client.connected_accounts.get_connected_account_by_identifier(
            connector=self.test_connector,
            identifier=get_identifier
        )
        self.assertEqual(get_response[1].code().name, "OK")
        self.assertTrue(get_response[0] is not None)
        self.assertTrue(hasattr(get_response[0], 'connected_account'))
        self.assertEqual(get_response[0].connected_account.identifier, get_identifier)

    def test_update_connected_account(self):
        """ Method to test update connected account """
        connected_account = self._create_oauth_connected_account()
        update_identifier = f"update_test_{self.test_identifier}"
        
        # First create a connected account
        create_response = self.scalekit_client.connected_accounts.create_connected_account(
            connector=self.test_connector,
            identifier=update_identifier,
            connected_account=connected_account
        )
        self.assertEqual(create_response[1].code().name, "OK")
        
        # Now update it
        updated_oauth_token = OauthToken(
            access_token="updated_access_token",
            refresh_token="updated_refresh_token",
            scopes=["read", "write", "admin"]
        )
        updated_auth_details = AuthorizationDetails(oauth_token=updated_oauth_token)
        
        update_connected_account = UpdateConnectedAccount(
            authorization_details=updated_auth_details
        )
        
        update_response = self.scalekit_client.connected_accounts.update_connected_account(
            connector=self.test_connector,
            identifier=update_identifier,
            connected_account=update_connected_account
        )
        self.assertEqual(update_response[1].code().name, "OK")
        self.assertTrue(update_response[0] is not None)
        self.assertTrue(hasattr(update_response[0], 'connected_account'))
        self.assertEqual(update_response[0].connected_account.identifier, update_identifier)

    def test_get_magic_link_for_connected_account(self):
        """ Method to test get magic link for connected account """
        connected_account = self._create_oauth_connected_account()
        magic_link_identifier = f"magic_link_test_{self.test_identifier}"
        
        # First create a connected account
        create_response = self.scalekit_client.connected_accounts.create_connected_account(
            connector=self.test_connector,
            identifier=magic_link_identifier,
            connected_account=connected_account
        )
        self.assertEqual(create_response[1].code().name, "OK")
        
        # Now get magic link
        magic_link_response = self.scalekit_client.connected_accounts.get_magic_link_for_connected_account(
            connector=self.test_connector,
            identifier=magic_link_identifier
        )
        self.assertEqual(magic_link_response[1].code().name, "OK")
        self.assertTrue(magic_link_response[0] is not None)
        self.assertTrue(hasattr(magic_link_response[0], 'link'))
        self.assertTrue(hasattr(magic_link_response[0], 'expiry'))

    def test_delete_connected_account(self):
        """ Method to test delete connected account """
        connected_account = self._create_oauth_connected_account()
        delete_identifier = f"delete_test_{self.test_identifier}"
        
        # First create a connected account
        create_response = self.scalekit_client.connected_accounts.create_connected_account(
            connector=self.test_connector,
            identifier=delete_identifier,
            connected_account=connected_account
        )
        self.assertEqual(create_response[1].code().name, "OK")
        
        # Now delete it
        delete_response = self.scalekit_client.connected_accounts.delete_connected_account(
            connector=self.test_connector,
            identifier=delete_identifier
        )
        self.assertEqual(delete_response[1].code().name, "OK")
        self.assertTrue(delete_response[0] is not None)

    def test_update_connected_account_with_connected_account_id(self):
        """ Method to test update connected account with connected_account_id parameter """
        connected_account = self._create_oauth_connected_account()
        update_identifier = f"update_with_id_test_{self.test_identifier}"
        
        # First create a connected account
        create_response = self.scalekit_client.connected_accounts.create_connected_account(
            connector=self.test_connector,
            identifier=update_identifier,
            connected_account=connected_account
        )
        self.assertEqual(create_response[1].code().name, "OK")
        created_account_id = create_response[0].connected_account.id
        
        # Now update it using connected_account_id
        updated_oauth_token = OauthToken(
            access_token="updated_with_id_access_token",
            refresh_token="updated_with_id_refresh_token",
            scopes=["read", "write", "admin"]
        )
        updated_auth_details = AuthorizationDetails(oauth_token=updated_oauth_token)
        
        update_connected_account = UpdateConnectedAccount(
            authorization_details=updated_auth_details
        )
        
        update_response = self.scalekit_client.connected_accounts.update_connected_account(
            connector=self.test_connector,
            identifier=update_identifier,
            connected_account=update_connected_account,
            connected_account_id=created_account_id
        )
        self.assertEqual(update_response[1].code().name, "OK")
        self.assertTrue(update_response[0] is not None)
        self.assertTrue(hasattr(update_response[0], 'connected_account'))
        self.assertEqual(update_response[0].connected_account.id, created_account_id)

    def test_get_connected_account_by_identifier_with_connected_account_id(self):
        """ Method to test get connected account by identifier with connected_account_id parameter """
        connected_account = self._create_oauth_connected_account()
        get_identifier = f"get_with_id_test_{self.test_identifier}"
        
        # First create a connected account
        create_response = self.scalekit_client.connected_accounts.create_connected_account(
            connector=self.test_connector,
            identifier=get_identifier,
            connected_account=connected_account
        )
        self.assertEqual(create_response[1].code().name, "OK")
        created_account_id = create_response[0].connected_account.id
        
        # Now get it by identifier with connected_account_id
        get_response = self.scalekit_client.connected_accounts.get_connected_account_by_identifier(
            connector=self.test_connector,
            identifier=get_identifier,
            connected_account_id=created_account_id
        )
        self.assertEqual(get_response[1].code().name, "OK")
        self.assertTrue(get_response[0] is not None)
        self.assertTrue(hasattr(get_response[0], 'connected_account'))
        self.assertEqual(get_response[0].connected_account.id, created_account_id)
        self.assertEqual(get_response[0].connected_account.identifier, get_identifier)

    def test_get_magic_link_for_connected_account_with_connected_account_id(self):
        """ Method to test get magic link for connected account with connected_account_id parameter """
        connected_account = self._create_oauth_connected_account()
        magic_link_identifier = f"magic_link_with_id_test_{self.test_identifier}"
        
        # First create a connected account
        create_response = self.scalekit_client.connected_accounts.create_connected_account(
            connector=self.test_connector,
            identifier=magic_link_identifier,
            connected_account=connected_account
        )
        self.assertEqual(create_response[1].code().name, "OK")
        created_account_id = create_response[0].connected_account.id
        
        # Now get magic link with connected_account_id
        magic_link_response = self.scalekit_client.connected_accounts.get_magic_link_for_connected_account(
            connector=self.test_connector,
            identifier=magic_link_identifier,
            connected_account_id=created_account_id
        )
        self.assertEqual(magic_link_response[1].code().name, "OK")
        self.assertTrue(magic_link_response[0] is not None)
        self.assertTrue(hasattr(magic_link_response[0], 'link'))
        self.assertTrue(hasattr(magic_link_response[0], 'expiry'))

    def test_delete_connected_account_with_connected_account_id(self):
        """ Method to test delete connected account with connected_account_id parameter """
        connected_account = self._create_oauth_connected_account()
        delete_identifier = f"delete_with_id_test_{self.test_identifier}"
        
        # First create a connected account
        create_response = self.scalekit_client.connected_accounts.create_connected_account(
            connector=self.test_connector,
            identifier=delete_identifier,
            connected_account=connected_account
        )
        self.assertEqual(create_response[1].code().name, "OK")
        created_account_id = create_response[0].connected_account.id
        
        # Now delete it using connected_account_id
        delete_response = self.scalekit_client.connected_accounts.delete_connected_account(
            connector=self.test_connector,
            identifier=delete_identifier,
            connected_account_id=created_account_id
        )
        self.assertEqual(delete_response[1].code().name, "OK")
        self.assertTrue(delete_response[0] is not None)

    def test_backward_compatibility_without_connected_account_id(self):
        """ Method to test that all methods still work without connected_account_id (backward compatibility) """
        connected_account = self._create_oauth_connected_account()
        compat_identifier = f"compat_test_{self.test_identifier}"
        
        # Test create (no connected_account_id parameter in create, so this is just baseline)
        create_response = self.scalekit_client.connected_accounts.create_connected_account(
            connector=self.test_connector,
            identifier=compat_identifier,
            connected_account=connected_account
        )
        self.assertEqual(create_response[1].code().name, "OK")
        
        # Test get without connected_account_id (backward compatibility)
        get_response = self.scalekit_client.connected_accounts.get_connected_account_by_identifier(
            connector=self.test_connector,
            identifier=compat_identifier
        )
        self.assertEqual(get_response[1].code().name, "OK")
        self.assertTrue(hasattr(get_response[0], 'connected_account'))
        
        # Test magic link without connected_account_id (backward compatibility)  
        magic_link_response = self.scalekit_client.connected_accounts.get_magic_link_for_connected_account(
            connector=self.test_connector,
            identifier=compat_identifier
        )
        self.assertEqual(magic_link_response[1].code().name, "OK")
        self.assertTrue(hasattr(magic_link_response[0], 'link'))
        
        # Test update without connected_account_id (backward compatibility)
        updated_oauth_token = OauthToken(
            access_token="compat_updated_access_token",
            refresh_token="compat_updated_refresh_token",
            scopes=["read", "write"]
        )
        updated_auth_details = AuthorizationDetails(oauth_token=updated_oauth_token)
        update_connected_account = UpdateConnectedAccount(authorization_details=updated_auth_details)
        
        update_response = self.scalekit_client.connected_accounts.update_connected_account(
            connector=self.test_connector,
            identifier=compat_identifier,
            connected_account=update_connected_account
        )
        self.assertEqual(update_response[1].code().name, "OK")
        
        # Test delete without connected_account_id (backward compatibility)
        delete_response = self.scalekit_client.connected_accounts.delete_connected_account(
            connector=self.test_connector,
            identifier=compat_identifier
        )
        self.assertEqual(delete_response[1].code().name, "OK")


from buf.validate import validate_pb2 as _validate_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from protoc_gen_openapiv2.options import annotations_pb2 as _annotations_pb2_1
from scalekit.v1.commons import commons_pb2 as _commons_pb2
from scalekit.v1.options import options_pb2 as _options_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TOTPRegistrationRequest(_message.Message):
    __slots__ = ("totp_registration",)
    TOTP_REGISTRATION_FIELD_NUMBER: _ClassVar[int]
    totp_registration: TOTPRegistration
    def __init__(self, totp_registration: _Optional[_Union[TOTPRegistration, _Mapping]] = ...) -> None: ...

class TOTPRegistrationResponse(_message.Message):
    __slots__ = ("totp_registration",)
    TOTP_REGISTRATION_FIELD_NUMBER: _ClassVar[int]
    totp_registration: TOTPRegistration
    def __init__(self, totp_registration: _Optional[_Union[TOTPRegistration, _Mapping]] = ...) -> None: ...

class TOTPRegistration(_message.Message):
    __slots__ = ("id", "create_time", "update_time", "user_id", "account_name", "qr_code_uri")
    ID_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    ACCOUNT_NAME_FIELD_NUMBER: _ClassVar[int]
    QR_CODE_URI_FIELD_NUMBER: _ClassVar[int]
    id: str
    create_time: _timestamp_pb2.Timestamp
    update_time: _timestamp_pb2.Timestamp
    user_id: str
    account_name: str
    qr_code_uri: str
    def __init__(self, id: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., user_id: _Optional[str] = ..., account_name: _Optional[str] = ..., qr_code_uri: _Optional[str] = ...) -> None: ...

class EnableRegistrationTOTPRequest(_message.Message):
    __slots__ = ("registration_id", "code")
    REGISTRATION_ID_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    registration_id: str
    code: str
    def __init__(self, registration_id: _Optional[str] = ..., code: _Optional[str] = ...) -> None: ...

class EnableRegistrationTOTPResponse(_message.Message):
    __slots__ = ("id", "backup_codes")
    ID_FIELD_NUMBER: _ClassVar[int]
    BACKUP_CODES_FIELD_NUMBER: _ClassVar[int]
    id: str
    backup_codes: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, id: _Optional[str] = ..., backup_codes: _Optional[_Iterable[str]] = ...) -> None: ...

class DisableRegistrationTOTPRequest(_message.Message):
    __slots__ = ("registration_id", "code")
    REGISTRATION_ID_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    registration_id: str
    code: str
    def __init__(self, registration_id: _Optional[str] = ..., code: _Optional[str] = ...) -> None: ...

class GenerateQRCodeRequest(_message.Message):
    __slots__ = ("environment_id", "identifier", "is_user")
    ENVIRONMENT_ID_FIELD_NUMBER: _ClassVar[int]
    IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    IS_USER_FIELD_NUMBER: _ClassVar[int]
    environment_id: str
    identifier: str
    is_user: bool
    def __init__(self, environment_id: _Optional[str] = ..., identifier: _Optional[str] = ..., is_user: bool = ...) -> None: ...

class GenerateQRCodeResponse(_message.Message):
    __slots__ = ("qr_code",)
    QR_CODE_FIELD_NUMBER: _ClassVar[int]
    qr_code: str
    def __init__(self, qr_code: _Optional[str] = ...) -> None: ...

class VerifyUserCodeRequest(_message.Message):
    __slots__ = ("user_id", "code")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    code: str
    def __init__(self, user_id: _Optional[str] = ..., code: _Optional[str] = ...) -> None: ...

class VerifyCodeResponse(_message.Message):
    __slots__ = ("valid",)
    VALID_FIELD_NUMBER: _ClassVar[int]
    valid: bool
    def __init__(self, valid: bool = ...) -> None: ...

class VerifyRegistrationCodeRequest(_message.Message):
    __slots__ = ("registration_id", "code")
    REGISTRATION_ID_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    registration_id: str
    code: str
    def __init__(self, registration_id: _Optional[str] = ..., code: _Optional[str] = ...) -> None: ...



from buf.validate import validate_pb2 as _validate_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.api import visibility_pb2 as _visibility_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from protoc_gen_openapiv2.options import annotations_pb2 as _annotations_pb2_1
from scalekit.v1.commons import commons_pb2 as _commons_pb2
from scalekit.v1.connections import connections_pb2 as _connections_pb2
from scalekit.v1.options import options_pb2 as _options_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Intent(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    INTENT_UNSPECIFIED: _ClassVar[Intent]
    sign_in: _ClassVar[Intent]
    sign_up: _ClassVar[Intent]

class AuthState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    AUTH_STATE_UNSPECIFIED: _ClassVar[AuthState]
    AUTHENTICATION_IN_PROGRESS: _ClassVar[AuthState]
    ORGANIZATION_SWITCHER: _ClassVar[AuthState]
    ORGANIZATION_SELECTED: _ClassVar[AuthState]
    ORGANIZATION_SIGNUP: _ClassVar[AuthState]
    ORGANIZATION_SWITCHER_SIGNUP: _ClassVar[AuthState]
    OTP_VERIFICATION_PENDING: _ClassVar[AuthState]
    MAGIC_LINK_SENT: _ClassVar[AuthState]
    LINK_SENT_OTP_VERIFICATION_PENDING: _ClassVar[AuthState]
    OTP_VERIFIED: _ClassVar[AuthState]
    LINK_VERIFIED: _ClassVar[AuthState]
    SSO_AUTHENTICATED: _ClassVar[AuthState]
    ORG_USER_CREATED: _ClassVar[AuthState]
    AUTHENTICATION_COMPLETED: _ClassVar[AuthState]
    AUTHENTICATION_FAILED: _ClassVar[AuthState]
INTENT_UNSPECIFIED: Intent
sign_in: Intent
sign_up: Intent
AUTH_STATE_UNSPECIFIED: AuthState
AUTHENTICATION_IN_PROGRESS: AuthState
ORGANIZATION_SWITCHER: AuthState
ORGANIZATION_SELECTED: AuthState
ORGANIZATION_SIGNUP: AuthState
ORGANIZATION_SWITCHER_SIGNUP: AuthState
OTP_VERIFICATION_PENDING: AuthState
MAGIC_LINK_SENT: AuthState
LINK_SENT_OTP_VERIFICATION_PENDING: AuthState
OTP_VERIFIED: AuthState
LINK_VERIFIED: AuthState
SSO_AUTHENTICATED: AuthState
ORG_USER_CREATED: AuthState
AUTHENTICATION_COMPLETED: AuthState
AUTHENTICATION_FAILED: AuthState

class ListAuthMethodsRequest(_message.Message):
    __slots__ = ("intent",)
    INTENT_FIELD_NUMBER: _ClassVar[int]
    intent: str
    def __init__(self, intent: _Optional[str] = ...) -> None: ...

class ListAuthMethodsResponse(_message.Message):
    __slots__ = ("auth_methods",)
    AUTH_METHODS_FIELD_NUMBER: _ClassVar[int]
    auth_methods: _containers.RepeatedCompositeFieldContainer[AuthMethod]
    def __init__(self, auth_methods: _Optional[_Iterable[_Union[AuthMethod, _Mapping]]] = ...) -> None: ...

class AuthMethod(_message.Message):
    __slots__ = ("connection_id", "connection_type", "provider", "auth_initiation_uri", "passwordless_type", "code_challenge_length")
    CONNECTION_ID_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_TYPE_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    AUTH_INITIATION_URI_FIELD_NUMBER: _ClassVar[int]
    PASSWORDLESS_TYPE_FIELD_NUMBER: _ClassVar[int]
    CODE_CHALLENGE_LENGTH_FIELD_NUMBER: _ClassVar[int]
    connection_id: str
    connection_type: _connections_pb2.ConnectionType
    provider: str
    auth_initiation_uri: str
    passwordless_type: _connections_pb2.PasswordlessType
    code_challenge_length: int
    def __init__(self, connection_id: _Optional[str] = ..., connection_type: _Optional[_Union[_connections_pb2.ConnectionType, str]] = ..., provider: _Optional[str] = ..., auth_initiation_uri: _Optional[str] = ..., passwordless_type: _Optional[_Union[_connections_pb2.PasswordlessType, str]] = ..., code_challenge_length: _Optional[int] = ...) -> None: ...

class DiscoveryAuthMethodRequest(_message.Message):
    __slots__ = ("discovery_request",)
    DISCOVERY_REQUEST_FIELD_NUMBER: _ClassVar[int]
    discovery_request: DiscoveryRequest
    def __init__(self, discovery_request: _Optional[_Union[DiscoveryRequest, _Mapping]] = ...) -> None: ...

class DiscoveryRequest(_message.Message):
    __slots__ = ("email", "intent")
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    INTENT_FIELD_NUMBER: _ClassVar[int]
    email: str
    intent: Intent
    def __init__(self, email: _Optional[str] = ..., intent: _Optional[_Union[Intent, str]] = ...) -> None: ...

class DiscoveryAuthMethodResponse(_message.Message):
    __slots__ = ("auth_method",)
    AUTH_METHOD_FIELD_NUMBER: _ClassVar[int]
    auth_method: AuthMethod
    def __init__(self, auth_method: _Optional[_Union[AuthMethod, _Mapping]] = ...) -> None: ...

class GetAuthCustomizationsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetAuthCustomizationsResponse(_message.Message):
    __slots__ = ("customization_settings",)
    CUSTOMIZATION_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    customization_settings: _struct_pb2.Struct
    def __init__(self, customization_settings: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class GetAuthFeaturesResponse(_message.Message):
    __slots__ = ("features",)
    FEATURES_FIELD_NUMBER: _ClassVar[int]
    features: _struct_pb2.Struct
    def __init__(self, features: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class VerifyPasswordLessRequest(_message.Message):
    __slots__ = ("otp_req",)
    OTP_REQ_FIELD_NUMBER: _ClassVar[int]
    otp_req: OTPRequest
    def __init__(self, otp_req: _Optional[_Union[OTPRequest, _Mapping]] = ...) -> None: ...

class VerifyPasswordLessResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class OTPRequest(_message.Message):
    __slots__ = ("code_challenge",)
    CODE_CHALLENGE_FIELD_NUMBER: _ClassVar[int]
    code_challenge: str
    def __init__(self, code_challenge: _Optional[str] = ...) -> None: ...

class ListUserOrganizationsResponse(_message.Message):
    __slots__ = ("organizations", "user", "intent")
    ORGANIZATIONS_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    INTENT_FIELD_NUMBER: _ClassVar[int]
    organizations: _containers.RepeatedCompositeFieldContainer[Organization]
    user: UserDetails
    intent: Intent
    def __init__(self, organizations: _Optional[_Iterable[_Union[Organization, _Mapping]]] = ..., user: _Optional[_Union[UserDetails, _Mapping]] = ..., intent: _Optional[_Union[Intent, str]] = ...) -> None: ...

class Organization(_message.Message):
    __slots__ = ("id", "name", "membership_status", "invitation_invited_by", "invitation_accepted_at", "invitation_created_at", "invitation_expires_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    MEMBERSHIP_STATUS_FIELD_NUMBER: _ClassVar[int]
    INVITATION_INVITED_BY_FIELD_NUMBER: _ClassVar[int]
    INVITATION_ACCEPTED_AT_FIELD_NUMBER: _ClassVar[int]
    INVITATION_CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    INVITATION_EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    membership_status: str
    invitation_invited_by: str
    invitation_accepted_at: _timestamp_pb2.Timestamp
    invitation_created_at: _timestamp_pb2.Timestamp
    invitation_expires_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., membership_status: _Optional[str] = ..., invitation_invited_by: _Optional[str] = ..., invitation_accepted_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., invitation_created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., invitation_expires_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class UserDetails(_message.Message):
    __slots__ = ("email", "first_name", "last_name")
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    FIRST_NAME_FIELD_NUMBER: _ClassVar[int]
    LAST_NAME_FIELD_NUMBER: _ClassVar[int]
    email: str
    first_name: str
    last_name: str
    def __init__(self, email: _Optional[str] = ..., first_name: _Optional[str] = ..., last_name: _Optional[str] = ...) -> None: ...

class SignupOrganizationRequest(_message.Message):
    __slots__ = ("organization_name", "first_name", "last_name", "full_name", "phone_number")
    ORGANIZATION_NAME_FIELD_NUMBER: _ClassVar[int]
    FIRST_NAME_FIELD_NUMBER: _ClassVar[int]
    LAST_NAME_FIELD_NUMBER: _ClassVar[int]
    FULL_NAME_FIELD_NUMBER: _ClassVar[int]
    PHONE_NUMBER_FIELD_NUMBER: _ClassVar[int]
    organization_name: str
    first_name: str
    last_name: str
    full_name: str
    phone_number: str
    def __init__(self, organization_name: _Optional[str] = ..., first_name: _Optional[str] = ..., last_name: _Optional[str] = ..., full_name: _Optional[str] = ..., phone_number: _Optional[str] = ...) -> None: ...

class SignupOrganizationResponse(_message.Message):
    __slots__ = ("organization_id", "organization_name")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATION_NAME_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    organization_name: str
    def __init__(self, organization_id: _Optional[str] = ..., organization_name: _Optional[str] = ...) -> None: ...

class UpdateLoginUserDetailsRequest(_message.Message):
    __slots__ = ("connection_id", "login_request_id", "user")
    CONNECTION_ID_FIELD_NUMBER: _ClassVar[int]
    LOGIN_REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    connection_id: str
    login_request_id: str
    user: User
    def __init__(self, connection_id: _Optional[str] = ..., login_request_id: _Optional[str] = ..., user: _Optional[_Union[User, _Mapping]] = ...) -> None: ...

class User(_message.Message):
    __slots__ = ("sub", "email", "given_name", "family_name", "email_verified", "phone_number", "phone_number_verified", "name", "preferred_username", "picture", "gender", "locale", "groups", "custom_attributes")
    SUB_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    GIVEN_NAME_FIELD_NUMBER: _ClassVar[int]
    FAMILY_NAME_FIELD_NUMBER: _ClassVar[int]
    EMAIL_VERIFIED_FIELD_NUMBER: _ClassVar[int]
    PHONE_NUMBER_FIELD_NUMBER: _ClassVar[int]
    PHONE_NUMBER_VERIFIED_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PREFERRED_USERNAME_FIELD_NUMBER: _ClassVar[int]
    PICTURE_FIELD_NUMBER: _ClassVar[int]
    GENDER_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    sub: str
    email: str
    given_name: str
    family_name: str
    email_verified: bool
    phone_number: str
    phone_number_verified: bool
    name: str
    preferred_username: str
    picture: str
    gender: str
    locale: str
    groups: _containers.RepeatedScalarFieldContainer[str]
    custom_attributes: _struct_pb2.Struct
    def __init__(self, sub: _Optional[str] = ..., email: _Optional[str] = ..., given_name: _Optional[str] = ..., family_name: _Optional[str] = ..., email_verified: bool = ..., phone_number: _Optional[str] = ..., phone_number_verified: bool = ..., name: _Optional[str] = ..., preferred_username: _Optional[str] = ..., picture: _Optional[str] = ..., gender: _Optional[str] = ..., locale: _Optional[str] = ..., groups: _Optional[_Iterable[str]] = ..., custom_attributes: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class GetAuthStateResponse(_message.Message):
    __slots__ = ("auth_state",)
    AUTH_STATE_FIELD_NUMBER: _ClassVar[int]
    auth_state: AuthState
    def __init__(self, auth_state: _Optional[_Union[AuthState, str]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from scalekit.v1.clients import clients_pb2 as scalekit_dot_v1_dot_clients_dot_clients__pb2


class ClientServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListClient = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/ListClient',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListClientsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListClientsResponse.FromString,
                )
        self.GetClient = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/GetClient',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetClientRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetClientResponse.FromString,
                )
        self.UpdateClient = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/UpdateClient',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateClientRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateClientResponse.FromString,
                )
        self.CreateClientSecret = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/CreateClientSecret',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateClientSecretRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateClientSecretResponse.FromString,
                )
        self.UpdateClientSecret = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/UpdateClientSecret',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateClientSecretRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateClientSecretResponse.FromString,
                )
        self.DeleteClientSecret = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/DeleteClientSecret',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteClientSecretRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CreateOrganizationClient = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/CreateOrganizationClient',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateOrganizationClientRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateOrganizationClientResponse.FromString,
                )
        self.GetOrganizationClient = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/GetOrganizationClient',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetOrganizationClientRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetOrganizationClientResponse.FromString,
                )
        self.CreateOrganizationClientSecret = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/CreateOrganizationClientSecret',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateOrganizationClientSecretRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateOrganizationClientSecretResponse.FromString,
                )
        self.DeleteOrganizationClientSecret = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/DeleteOrganizationClientSecret',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteOrganizationClientSecretRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateOrganizationClient = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/UpdateOrganizationClient',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateOrganizationClientRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateOrganizationClientResponse.FromString,
                )
        self.DeleteOrganizationClient = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/DeleteOrganizationClient',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteOrganizationClientRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListOrganizationClients = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/ListOrganizationClients',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListOrganizationClientsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListOrganizationClientsResponse.FromString,
                )
        self.CreateResource = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/CreateResource',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateResourceRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateResourceResponse.FromString,
                )
        self.GetResource = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/GetResource',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceResponse.FromString,
                )
        self.ListResources = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/ListResources',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListResourcesRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListResourcesResponse.FromString,
                )
        self.UpdateResource = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/UpdateResource',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateResourceRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateResourceResponse.FromString,
                )
        self.DeleteResource = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/DeleteResource',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteResourceRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeleteResourceProvider = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/DeleteResourceProvider',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteResourceProviderRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceResponse.FromString,
                )
        self.CreateResourceClient = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/CreateResourceClient',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateResourceClientRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateResourceClientResponse.FromString,
                )
        self.GetResourceClient = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/GetResourceClient',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceClientRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceClientResponse.FromString,
                )
        self.RegisterClient = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/RegisterClient',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.RegisterClientRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.RegisterClientResponse.FromString,
                )
        self.CreateScope = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/CreateScope',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateScopeRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateScopeResponse.FromString,
                )
        self.ListScopes = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/ListScopes',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListScopesRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListScopesResponse.FromString,
                )
        self.UpdateScope = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/UpdateScope',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateScopeRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateScopeResponse.FromString,
                )
        self.DeleteScope = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/DeleteScope',
                request_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteScopeRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetConsentDetails = channel.unary_unary(
                '/scalekit.v1.clients.ClientService/GetConsentDetails',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetConsentDetailsResponse.FromString,
                )


class ClientServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListClient(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetClient(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateClient(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateClientSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateClientSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteClientSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateOrganizationClient(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationClient(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateOrganizationClientSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOrganizationClientSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateOrganizationClient(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOrganizationClient(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOrganizationClients(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateResource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetResource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListResources(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateResource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteResource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteResourceProvider(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateResourceClient(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetResourceClient(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterClient(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateScope(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListScopes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateScope(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteScope(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetConsentDetails(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ClientServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListClient': grpc.unary_unary_rpc_method_handler(
                    servicer.ListClient,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListClientsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListClientsResponse.SerializeToString,
            ),
            'GetClient': grpc.unary_unary_rpc_method_handler(
                    servicer.GetClient,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetClientRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetClientResponse.SerializeToString,
            ),
            'UpdateClient': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateClient,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateClientRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateClientResponse.SerializeToString,
            ),
            'CreateClientSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateClientSecret,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateClientSecretRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateClientSecretResponse.SerializeToString,
            ),
            'UpdateClientSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateClientSecret,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateClientSecretRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateClientSecretResponse.SerializeToString,
            ),
            'DeleteClientSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteClientSecret,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteClientSecretRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateOrganizationClient': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrganizationClient,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateOrganizationClientRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateOrganizationClientResponse.SerializeToString,
            ),
            'GetOrganizationClient': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationClient,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetOrganizationClientRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetOrganizationClientResponse.SerializeToString,
            ),
            'CreateOrganizationClientSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrganizationClientSecret,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateOrganizationClientSecretRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateOrganizationClientSecretResponse.SerializeToString,
            ),
            'DeleteOrganizationClientSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOrganizationClientSecret,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteOrganizationClientSecretRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateOrganizationClient': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateOrganizationClient,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateOrganizationClientRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateOrganizationClientResponse.SerializeToString,
            ),
            'DeleteOrganizationClient': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOrganizationClient,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteOrganizationClientRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListOrganizationClients': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOrganizationClients,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListOrganizationClientsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListOrganizationClientsResponse.SerializeToString,
            ),
            'CreateResource': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateResource,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateResourceRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateResourceResponse.SerializeToString,
            ),
            'GetResource': grpc.unary_unary_rpc_method_handler(
                    servicer.GetResource,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceResponse.SerializeToString,
            ),
            'ListResources': grpc.unary_unary_rpc_method_handler(
                    servicer.ListResources,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListResourcesRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListResourcesResponse.SerializeToString,
            ),
            'UpdateResource': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateResource,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateResourceRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateResourceResponse.SerializeToString,
            ),
            'DeleteResource': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteResource,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteResourceRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeleteResourceProvider': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteResourceProvider,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteResourceProviderRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceResponse.SerializeToString,
            ),
            'CreateResourceClient': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateResourceClient,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateResourceClientRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateResourceClientResponse.SerializeToString,
            ),
            'GetResourceClient': grpc.unary_unary_rpc_method_handler(
                    servicer.GetResourceClient,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceClientRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceClientResponse.SerializeToString,
            ),
            'RegisterClient': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterClient,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.RegisterClientRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.RegisterClientResponse.SerializeToString,
            ),
            'CreateScope': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateScope,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateScopeRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateScopeResponse.SerializeToString,
            ),
            'ListScopes': grpc.unary_unary_rpc_method_handler(
                    servicer.ListScopes,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListScopesRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.ListScopesResponse.SerializeToString,
            ),
            'UpdateScope': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateScope,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateScopeRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateScopeResponse.SerializeToString,
            ),
            'DeleteScope': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteScope,
                    request_deserializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteScopeRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetConsentDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConsentDetails,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=scalekit_dot_v1_dot_clients_dot_clients__pb2.GetConsentDetailsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'scalekit.v1.clients.ClientService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ClientService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/ListClient',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.ListClientsRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.ListClientsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/GetClient',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.GetClientRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.GetClientResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/UpdateClient',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateClientRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateClientResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateClientSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/CreateClientSecret',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateClientSecretRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateClientSecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateClientSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/UpdateClientSecret',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateClientSecretRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateClientSecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteClientSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/DeleteClientSecret',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteClientSecretRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateOrganizationClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/CreateOrganizationClient',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateOrganizationClientRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateOrganizationClientResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/GetOrganizationClient',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.GetOrganizationClientRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.GetOrganizationClientResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateOrganizationClientSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/CreateOrganizationClientSecret',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateOrganizationClientSecretRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateOrganizationClientSecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOrganizationClientSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/DeleteOrganizationClientSecret',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteOrganizationClientSecretRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateOrganizationClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/UpdateOrganizationClient',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateOrganizationClientRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateOrganizationClientResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOrganizationClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/DeleteOrganizationClient',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteOrganizationClientRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOrganizationClients(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/ListOrganizationClients',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.ListOrganizationClientsRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.ListOrganizationClientsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateResource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/CreateResource',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateResourceRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateResourceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetResource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/GetResource',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListResources(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/ListResources',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.ListResourcesRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.ListResourcesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateResource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/UpdateResource',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateResourceRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateResourceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteResource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/DeleteResource',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteResourceRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteResourceProvider(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/DeleteResourceProvider',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteResourceProviderRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateResourceClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/CreateResourceClient',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateResourceClientRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateResourceClientResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetResourceClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/GetResourceClient',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceClientRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.GetResourceClientResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/RegisterClient',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.RegisterClientRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.RegisterClientResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateScope(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/CreateScope',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateScopeRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.CreateScopeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListScopes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/ListScopes',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.ListScopesRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.ListScopesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateScope(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/UpdateScope',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateScopeRequest.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.UpdateScopeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteScope(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/DeleteScope',
            scalekit_dot_v1_dot_clients_dot_clients__pb2.DeleteScopeRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetConsentDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.clients.ClientService/GetConsentDetails',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            scalekit_dot_v1_dot_clients_dot_clients__pb2.GetConsentDetailsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from typing import Optional, List
from pydantic import BaseModel, Field, field_validator

from scalekit.connect.models.tool_mapping import ToolMapping

# TODO: Add validation for tool_mappings to ensure unique tool names across mappings
class McpRequest(BaseModel):
    """MCP request configuration with validation"""


    identifier: Optional[str] = Field(
        None,
        description="Identifier for the connected account", 
        min_length=1,
        max_length=255
    )
    tool_mappings: List[ToolMapping]


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from scalekit.v1.domains import domains_pb2 as scalekit_dot_v1_dot_domains_dot_domains__pb2


class DomainServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateDomain = channel.unary_unary(
                '/scalekit.v1.domains.DomainService/CreateDomain',
                request_serializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.CreateDomainRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.CreateDomainResponse.FromString,
                )
        self.UpdateDomain = channel.unary_unary(
                '/scalekit.v1.domains.DomainService/UpdateDomain',
                request_serializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.UpdateDomainRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.UpdateDomainResponse.FromString,
                )
        self.VerifyDomain = channel.unary_unary(
                '/scalekit.v1.domains.DomainService/VerifyDomain',
                request_serializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.VerifyDomainRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_wrappers__pb2.BoolValue.FromString,
                )
        self.GetDomain = channel.unary_unary(
                '/scalekit.v1.domains.DomainService/GetDomain',
                request_serializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.GetDomainRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.GetDomainResponse.FromString,
                )
        self.DeleteDomain = channel.unary_unary(
                '/scalekit.v1.domains.DomainService/DeleteDomain',
                request_serializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.DeleteDomainRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListDomains = channel.unary_unary(
                '/scalekit.v1.domains.DomainService/ListDomains',
                request_serializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.ListDomainRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.ListDomainResponse.FromString,
                )
        self.ListAuthorizedDomains = channel.unary_unary(
                '/scalekit.v1.domains.DomainService/ListAuthorizedDomains',
                request_serializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.ListAuthorizedDomainRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.ListAuthorizedDomainResponse.FromString,
                )


class DomainServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateDomain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDomain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VerifyDomain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDomain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDomain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDomains(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAuthorizedDomains(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DomainServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDomain,
                    request_deserializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.CreateDomainRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.CreateDomainResponse.SerializeToString,
            ),
            'UpdateDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDomain,
                    request_deserializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.UpdateDomainRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.UpdateDomainResponse.SerializeToString,
            ),
            'VerifyDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.VerifyDomain,
                    request_deserializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.VerifyDomainRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_wrappers__pb2.BoolValue.SerializeToString,
            ),
            'GetDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDomain,
                    request_deserializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.GetDomainRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.GetDomainResponse.SerializeToString,
            ),
            'DeleteDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDomain,
                    request_deserializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.DeleteDomainRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListDomains': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDomains,
                    request_deserializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.ListDomainRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.ListDomainResponse.SerializeToString,
            ),
            'ListAuthorizedDomains': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAuthorizedDomains,
                    request_deserializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.ListAuthorizedDomainRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_domains_dot_domains__pb2.ListAuthorizedDomainResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'scalekit.v1.domains.DomainService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DomainService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.domains.DomainService/CreateDomain',
            scalekit_dot_v1_dot_domains_dot_domains__pb2.CreateDomainRequest.SerializeToString,
            scalekit_dot_v1_dot_domains_dot_domains__pb2.CreateDomainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.domains.DomainService/UpdateDomain',
            scalekit_dot_v1_dot_domains_dot_domains__pb2.UpdateDomainRequest.SerializeToString,
            scalekit_dot_v1_dot_domains_dot_domains__pb2.UpdateDomainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def VerifyDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.domains.DomainService/VerifyDomain',
            scalekit_dot_v1_dot_domains_dot_domains__pb2.VerifyDomainRequest.SerializeToString,
            google_dot_protobuf_dot_wrappers__pb2.BoolValue.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.domains.DomainService/GetDomain',
            scalekit_dot_v1_dot_domains_dot_domains__pb2.GetDomainRequest.SerializeToString,
            scalekit_dot_v1_dot_domains_dot_domains__pb2.GetDomainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.domains.DomainService/DeleteDomain',
            scalekit_dot_v1_dot_domains_dot_domains__pb2.DeleteDomainRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDomains(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.domains.DomainService/ListDomains',
            scalekit_dot_v1_dot_domains_dot_domains__pb2.ListDomainRequest.SerializeToString,
            scalekit_dot_v1_dot_domains_dot_domains__pb2.ListDomainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAuthorizedDomains(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.domains.DomainService/ListAuthorizedDomains',
            scalekit_dot_v1_dot_domains_dot_domains__pb2.ListAuthorizedDomainRequest.SerializeToString,
            scalekit_dot_v1_dot_domains_dot_domains__pb2.ListAuthorizedDomainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from typing import Optional, Any, List, Dict
from scalekit.v1.mcp.mcp_pb2 import Mcp
from scalekit.v1.mcp.mcp_pb2 import ToolMapping as ProtoToolMapping

from scalekit.connect.models.tool_mapping import ToolMapping
from scalekit.connect.types import ToolRequest,ExecuteToolResponse,MagicLinkResponse,ListConnectedAccountsResponse,DeleteConnectedAccountResponse,GetConnectedAccountAuthResponse,ToolInput, \
    McpRequest,CreateMcpResponse,GetMcpResponse
from scalekit.connect.models.responses.create_connected_account_response import CreateConnectedAccountResponse
from scalekit.connect.models.requests.create_connected_account_request import CreateConnectedAccountRequest
from scalekit.connect.modifier import (
    Modifier, ModifierType, ToolNames,
    apply_pre_modifiers, apply_post_modifiers
)
from scalekit.connect.frameworks.langchain import LangChain
from scalekit.common.exceptions import ScalekitNotFoundException




class ConnectClient:
    """Class definition for Connect Client"""

    def __init__(self,tools_client, connected_accounts_client, mcp_client=None):
        """
        Initialize ConnectClient with tools, connected accounts, and MCP dependencies
        
        :param tools_client: ToolsClient instance
        :type: ToolsClient
        :param connected_accounts_client: ConnectedAccountsClient instance
        :type: ConnectedAccountsClient
        :param mcp_client: McpClient instance (optional)
        :type: McpClient
        
        :returns:
            None
        """

        self.tools = tools_client
        self.connected_accounts = connected_accounts_client
        self.mcp = mcp_client
        self._modifiers: List[Modifier] = []
        
        # Initialize LangChain with tools client and execute callback
        self.langchain = LangChain(tools_client, execute_callback=self.execute_tool)

    def execute_tool(
        self,
        tool_input:ToolInput,
        tool_name: str,
        identifier: Optional[str] = None,
        tool_request: Optional[ToolRequest] = None,
        connected_account_id: Optional[str] = None,
        **kwargs
    ) -> ExecuteToolResponse:
        """
        Execute a tool with the given parameters.
        
        Args:
            tool_input: Input data for the tool execution (required)
            tool_name: Name of the tool to execute (required)
            identifier: Unique identifier for this execution (required)
            tool_request: Optional ToolRequest configuration object
            connected_account_id: Optional connected account ID string
            **kwargs: Additional optional parameters
            
        Returns:
            ExecuteToolResponse containing execution results
        """
        # Validate required parameters
        if not tool_name:
            raise ValueError("tool_name is required")
        
        # Apply pre-modifications to the input parameters
        modified_tool_input = apply_pre_modifiers(tool_name, tool_input, self._modifiers)
        
        # Call the existing tools.execute_tool which returns (response, metadata) tuple
        result_tuple = self.tools.execute_tool(
            tool_name=tool_name,
            identifier=identifier,
            params=modified_tool_input,
            connected_account_id=connected_account_id
        )
        
        # Extract the response[0] (the actual ExecuteToolResponse proto object)
        proto_response = result_tuple[0]
        
        # Convert proto to our ExecuteToolResponse class
        response = ExecuteToolResponse.from_proto(proto_response)
        
        # Apply post-modifications to the result
        modified_response = apply_post_modifiers(tool_name, response.data, self._modifiers)

        response.data = modified_response
        
        return response
    
    def get_authorization_link(
            self,
            identifier: Optional[str] = None,
            connection_name: Optional[str] = None,
            connected_account_id: Optional[str] = None,
            **kwargs
    ) -> MagicLinkResponse:
        """
        Get authorization magic link for a connected account
        
        :param connection_name: Connector identifier
        :type: str
        :param identifier: Connected account identifier
        :type: str
        :param connected_account_id: Connected account ID (optional)
        :type: str
        
        :returns:
            MagicLinkResponse containing magic link and expiry
        """
        # Call the existing connected_accounts method which returns (response, metadata) tuple
        result_tuple = self.connected_accounts.get_magic_link_for_connected_account(
            connector=connection_name,
            identifier=identifier,
            connected_account_id=connected_account_id
        )
        
        # Extract the response[0] (the actual GetMagicLinkForConnectedAccountResponse proto object)
        proto_response = result_tuple[0]
        
        # Convert proto to our MagicLinkResponse class
        return MagicLinkResponse.from_proto(proto_response)
    
    def list_connected_accounts(
        self, 
        connection_name: Optional[str] = None,
        identifier: Optional[str] = None,
        provider: Optional[str] = None,
        **kwargs
    ) -> ListConnectedAccountsResponse:
        """
        List connected accounts with optional filtering
        
        :param connection_name: Connector identifier (optional)
        :type: str
        :param identifier: Identifier filter (optional)
        :type: str
        :param provider: Provider filter (optional)
        :type: str
        
        :returns:
            ListConnectedAccountsResponse containing list of connected accounts
        """
        # Call the existing connected_accounts method which returns (response, metadata) tuple
        result_tuple = self.connected_accounts.list_connected_accounts(
            connector=connection_name,
            identifier=identifier,
            provider=provider
        )
        
        # Extract the response[0] (the actual ListConnectedAccountsResponse proto object)
        proto_response = result_tuple[0]
        
        # Convert proto to our ListConnectedAccountsResponse class
        return ListConnectedAccountsResponse.from_proto(proto_response)
    
    def delete_connected_account(
        self,
        connection_name: Optional[str] = None,
        identifier: Optional[str] = None,
        connected_account_id: Optional[str] = None,
        **kwargs
    ) -> DeleteConnectedAccountResponse:
        """
        Delete a connected account
        
        :param connection_name: Connector identifier (required)
        :type: str
        :param identifier: Connected account identifier (required)
        :type: str
        :param connected_account_id: Connected account ID (optional)
        :type: str
        
        :returns:
            DeleteConnectedAccountResponse containing deletion status
        """
            
        # Call the existing connected_accounts method which returns (response, metadata) tuple
        result_tuple = self.connected_accounts.delete_connected_account(
            connector=connection_name,
            identifier=identifier,
            connected_account_id=connected_account_id
        )
        
        # Extract the response[0] (the actual DeleteConnectedAccountResponse proto object)
        proto_response = result_tuple[0]
        
        # Convert proto to our DeleteConnectedAccountResponse class
        return DeleteConnectedAccountResponse.from_proto(proto_response)
    
    def get_connected_account(
        self,
        connection_name: Optional[str] = None,
        identifier: Optional[str] = None,
        connected_account_id: Optional[str] = None,
        **kwargs
    ) -> GetConnectedAccountAuthResponse:
        """
        Get connected account authorization details by identifier
        
        :param connection_name: Connector identifier (required)
        :type: str
        :param identifier: Connected account identifier (required)
        :type: str
        :param connected_account_id: Connected account ID (optional)
        :type: str
        
        :returns:
            GetConnectedAccountAuthResponse containing connected account details
        """


            
        # Call the existing connected_accounts method which returns (response, metadata) tuple
        result_tuple = self.connected_accounts.get_connected_account_by_identifier(
            connector=connection_name,
            identifier=identifier,
            connected_account_id=connected_account_id
        )
        
        # Extract the response[0] (the actual GetConnectedAccountByIdentifierResponse proto object)
        proto_response = result_tuple[0]
        
        # Convert proto to our GetConnectedAccountAuthResponse class
        return GetConnectedAccountAuthResponse.from_proto(proto_response)
    
    def add_modifier(self, modifier: Modifier) -> None:
        """Add a modifier to the private list"""
        self._modifiers.append(modifier)
    
    def get_modifiers(
        self, 
        tool_name: Optional[str] = None, 
        modifier_type: Optional[ModifierType] = None
    ) -> List[Modifier]:
        """Get modifiers, optionally filtered by tool_name and/or type"""
        filtered = self._modifiers
        
        if tool_name:
            filtered = [m for m in filtered if tool_name in m.tool_names]
        
        if modifier_type:
            filtered = [m for m in filtered if m.type == modifier_type]
            
        return filtered
    
    def pre_modifier(self, tool_names: ToolNames, **kwargs: Any):
        """Decorator for pre-modification that registers with this Connect instance
        
        Usage:
            @connect.premodifier(tool_names="my_tool", priority=1)
            def my_modifier(tool_name, data):
                return modified_data
        """
        def decorator(func):
            modifier = Modifier(tool_names=tool_names, modifier_type="pre", **kwargs)
            modifier.func = func
            self.add_modifier(modifier)
            return func
        return decorator
    
    def post_modifier(self, tool_names: ToolNames, **kwargs: Any):
        """Decorator for post-modification that registers with this Connect instance
        
        Usage:
            @connect.postmodifier(tool_names=["tool1", "tool2"])
            def my_modifier(tool_name, result):
                return modified_result
        """
        def decorator(func):
            modifier = Modifier(tool_names=tool_names, modifier_type="post", **kwargs)
            modifier.func = func
            self.add_modifier(modifier)
            return func
        return decorator

    def get_mcp(
        self,
        mcp_id: str,
        mcp_request: Optional[McpRequest] = None,
        **kwargs
    ) -> GetMcpResponse:
        """
        Get an existing MCP by ID via the connect interface
        
        :param mcp_id: ID of the MCP to retrieve (required)
        :type: str
        :param mcp_request: Optional McpRequest configuration object
        :type: McpRequest
        
        :returns:
            GetMcpResponse containing MCP details
        """
        if not self.mcp:
            raise ValueError("MCP client not initialized. Please ensure MCP client is available.")
        
        if not mcp_id:
            raise ValueError("mcp_id is required")
        
        # Call the MCP client's get_mcp method which returns (response, metadata) tuple
        result_tuple = self.mcp.get_mcp(mcp_id=mcp_id)
        
        # Extract the response[0] (the actual GetMcpResponse proto object)
        proto_response = result_tuple[0]
        
        # Convert proto to our GetMcpResponse class
        return GetMcpResponse.from_proto(proto_response)

    def create_mcp(
        self,
        identifier: str,
        tool_mappings: List[ToolMapping],
        mcp_request: Optional[McpRequest] = None,
        **kwargs
    ) -> CreateMcpResponse:
        """
        Create or return existing MCP with given configuration via the connect interface
        
        :param identifier: Identifier for the connected account (required)
        :type: str
        :param tool_mappings: List of tool mappings for the MCP (required)
        :type: List[ToolMapping]
        :param mcp_request: Optional McpRequest configuration object
        :type: McpRequest
        
        :returns:
            CreateMcpResponse containing created MCP details
        """
        if not self.mcp:
            raise ValueError("MCP client not initialized. Please ensure MCP client is available.")
        
        # Validate required parameters
        if not identifier:
            raise ValueError("connected_account_identifier is required")
        if not tool_mappings:
            raise ValueError("tool_mappings is required")



        # Create ToolMapping objects from the provided tool_mappings
        proto_tool_mappings = []
        for mapping in tool_mappings:
            proto_mapping = ProtoToolMapping(
                tool_names=mapping.tool_names,
                connection_name=mapping.connection_name,
            )
            proto_tool_mappings.append(proto_mapping)
        
        # Create the MCP proto object
        mcp_proto = Mcp(
            connected_account_identifier=identifier,
            tool_mappings=proto_tool_mappings,
        )

        result_tuple = self.mcp.create_mcp(mcp=mcp_proto)
        
        # Extract the response[0] (the actual CreateMcpResponse proto object)
        proto_response = result_tuple[0]
        
        # Convert proto to our CreateMcpResponse class
        return CreateMcpResponse.from_proto(proto_response)

    def create_connected_account(
        self,
        connection_name: str,
        identifier: str, 
        authorization_details: Dict[str, Any],
        organization_id: Optional[str] = None,
        user_id: Optional[str] = None,
        **kwargs
    ) -> CreateConnectedAccountResponse:
        """
        Create a new connected account
        
        :param connection_name: Connector identifier (required)
        :type: str
        :param identifier: Connected account identifier (required)
        :type: str
        :param authorization_details: Authorization details (OAuth token or static auth) (required)
        :type: Dict[str, Any]
        :param organization_id: Organization ID (optional)
        :type: str
        :param user_id: User ID (optional)
        :type: str
        
        :returns:
            CreateConnectedAccountResponse containing created connected account details
        """
        # Validate required parameters
        if not connection_name:
            raise ValueError("connection_name is required")
        if not identifier:
            raise ValueError("identifier is required")
        if not authorization_details:
            raise ValueError("authorization_details is required")
        
        # Create request model
        request = CreateConnectedAccountRequest(
            connection_name=connection_name,
            identifier=identifier,
            authorization_details=authorization_details,
            organization_id=organization_id,
            user_id=user_id
        )
        
        # Convert to protobuf
        connected_account_proto = request.to_proto()
        
        # Call the existing connected_accounts method which returns (response, metadata) tuple
        result_tuple = self.connected_accounts.create_connected_account(
            connector=connection_name,
            identifier=identifier,
            connected_account=connected_account_proto,
            organization_id=organization_id,
            user_id=user_id
        )
        
        # Extract the response[0] (the actual CreateConnectedAccountResponse proto object)
        proto_response = result_tuple[0]
        
        # Convert proto to our CreateConnectedAccountResponse class
        return CreateConnectedAccountResponse.from_proto(proto_response)

    def get_or_create_connected_account(
        self,
        connection_name: str,
        identifier: str,
        authorization_details: Optional[Dict[str, Any]] = None,
        organization_id: Optional[str] = None,
        user_id: Optional[str] = None,
        **kwargs
    ) -> CreateConnectedAccountResponse:
        """
        Get an existing connected account or create a new one if it doesn't exist
        
        :param connection_name: Connector identifier (required)
        :type: str
        :param identifier: Connected account identifier (required)
        :type: str
        :param authorization_details: Authorization details (OAuth token or static auth) (optional, empty auth will be used if not provided)
        :type: Optional[Dict[str, Any]]
        :param organization_id: Organization ID (optional)
        :type: str
        :param user_id: User ID (optional)
        :type: str
        
        :returns:
            CreateConnectedAccountResponse containing connected account details (either existing or newly created)
        """
        if not connection_name:
            raise ValueError("connection_name is required")
        if not identifier:
            raise ValueError("identifier is required")

        try:
            # First, try to get the existing connected account
            existing_response = self.get_connected_account(
                connection_name=connection_name,
                identifier=identifier,
                organization_id=organization_id,
                user_id=user_id
            )
            
            # If we found it, convert the GetConnectedAccountAuthResponse to CreateConnectedAccountResponse format
            return CreateConnectedAccountResponse(connected_account=existing_response.connected_account)
            
        except ScalekitNotFoundException:
            # Connected account doesn't exist, create a new one
            # Use empty authorization details if none provided
            auth_details = authorization_details if authorization_details is not None else {}
            
            return self.create_connected_account(
                connection_name=connection_name,
                identifier=identifier,
                authorization_details=auth_details,
                organization_id=organization_id,
                user_id=user_id
            )



from scalekit.core import CoreClient
from scalekit.v1.domains.domains_pb2 import *
from scalekit.v1.domains.domains_pb2_grpc import DomainServiceStub


class DomainClient:
    """Class definition for Domain Client"""

    def __init__(self, core_client: CoreClient):
        """
        Initializer for Domain Client

        :param core_client    : CoreClient Object
        :type                 : ``` obj ```
        :returns
            None
        """
        self.core_client = core_client
        self.domain_service = DomainServiceStub(
            self.core_client.grpc_secure_channel
        )

    def create_domain(
        self, organization_id: str, domain_name: str
    ) -> CreateDomainResponse:
        """
        Method to create domain

        :param organization_id  : Organization id to create domain for
        :type                   : ``` str ```
        :param domain_name      : Domain name for new creation
        :type                   : ``` str ```
        :returns
            Domain Response
        """
        return self.core_client.grpc_exec(
            self.domain_service.CreateDomain.with_call,
            CreateDomainRequest(
                organization_id=organization_id,
                domain=CreateDomain(domain=domain_name),
            ),
        )

    def list_domains(self, organization_id: str) -> ListDomainResponse:
        """
        Method to list existing domains

        :param organization_id  : Organization id to list domains for
        :type                   : ``` str ```
        :returns
            List Domain Response
        """
        return self.core_client.grpc_exec(
            self.domain_service.ListDomains.with_call,
            ListDomainRequest(organization_id=organization_id),
            )

    def get_domain(self, organization_id: str, domain_id: str) -> GetDomainResponse:
        """
        Method to list existing domains

        :param organization_id  : Organization id to list domains for
        :type                   : ``` str ```
        :param domain_id        : Domain name for new creation
        :type                   : ``` str ```
        :returns
            Get Domain Response
        """
        return self.core_client.grpc_exec(
            self.domain_service.GetDomain.with_call,
            GetDomainRequest(organization_id=organization_id, id=domain_id),
        )



from buf.validate import validate_pb2 as _validate_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.api import visibility_pb2 as _visibility_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from protoc_gen_openapiv2.options import annotations_pb2 as _annotations_pb2_1
from scalekit.v1.options import options_pb2 as _options_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateToolRequest(_message.Message):
    __slots__ = ("tool",)
    TOOL_FIELD_NUMBER: _ClassVar[int]
    tool: Tool
    def __init__(self, tool: _Optional[_Union[Tool, _Mapping]] = ...) -> None: ...

class CreateToolResponse(_message.Message):
    __slots__ = ("tool",)
    TOOL_FIELD_NUMBER: _ClassVar[int]
    tool: Tool
    def __init__(self, tool: _Optional[_Union[Tool, _Mapping]] = ...) -> None: ...

class Tool(_message.Message):
    __slots__ = ("id", "provider", "definition", "metadata", "tags", "is_default", "updated_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    DEFINITION_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    IS_DEFAULT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    provider: str
    definition: _struct_pb2.Struct
    metadata: _struct_pb2.Struct
    tags: _containers.RepeatedScalarFieldContainer[str]
    is_default: _wrappers_pb2.BoolValue
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., provider: _Optional[str] = ..., definition: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., metadata: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., tags: _Optional[_Iterable[str]] = ..., is_default: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class ScopedTool(_message.Message):
    __slots__ = ("tool", "identifier", "connected_account_id")
    TOOL_FIELD_NUMBER: _ClassVar[int]
    IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    CONNECTED_ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    tool: Tool
    identifier: str
    connected_account_id: str
    def __init__(self, tool: _Optional[_Union[Tool, _Mapping]] = ..., identifier: _Optional[str] = ..., connected_account_id: _Optional[str] = ...) -> None: ...

class ListToolsRequest(_message.Message):
    __slots__ = ("filter", "page_size", "page_token")
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    filter: Filter
    page_size: int
    page_token: str
    def __init__(self, filter: _Optional[_Union[Filter, _Mapping]] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class Filter(_message.Message):
    __slots__ = ("summary", "provider", "identifier", "tool_name")
    SUMMARY_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    TOOL_NAME_FIELD_NUMBER: _ClassVar[int]
    summary: _wrappers_pb2.BoolValue
    provider: str
    identifier: str
    tool_name: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, summary: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., provider: _Optional[str] = ..., identifier: _Optional[str] = ..., tool_name: _Optional[_Iterable[str]] = ...) -> None: ...

class ListToolsResponse(_message.Message):
    __slots__ = ("next_page_token", "total_size", "prev_page_token", "tool_names", "tools")
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    PREV_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOOL_NAMES_FIELD_NUMBER: _ClassVar[int]
    TOOLS_FIELD_NUMBER: _ClassVar[int]
    next_page_token: str
    total_size: int
    prev_page_token: str
    tool_names: _containers.RepeatedScalarFieldContainer[str]
    tools: _containers.RepeatedCompositeFieldContainer[Tool]
    def __init__(self, next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ..., prev_page_token: _Optional[str] = ..., tool_names: _Optional[_Iterable[str]] = ..., tools: _Optional[_Iterable[_Union[Tool, _Mapping]]] = ...) -> None: ...

class ExecuteToolRequest(_message.Message):
    __slots__ = ("tool_name", "identifier", "params", "connected_account_id", "connector", "organization_id", "user_id")
    TOOL_NAME_FIELD_NUMBER: _ClassVar[int]
    IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    CONNECTED_ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    CONNECTOR_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    tool_name: str
    identifier: str
    params: _struct_pb2.Struct
    connected_account_id: str
    connector: str
    organization_id: str
    user_id: str
    def __init__(self, tool_name: _Optional[str] = ..., identifier: _Optional[str] = ..., params: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., connected_account_id: _Optional[str] = ..., connector: _Optional[str] = ..., organization_id: _Optional[str] = ..., user_id: _Optional[str] = ...) -> None: ...

class ExecuteToolResponse(_message.Message):
    __slots__ = ("data", "execution_id")
    DATA_FIELD_NUMBER: _ClassVar[int]
    EXECUTION_ID_FIELD_NUMBER: _ClassVar[int]
    data: _struct_pb2.Struct
    execution_id: str
    def __init__(self, data: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., execution_id: _Optional[str] = ...) -> None: ...

class SetToolDefaultRequest(_message.Message):
    __slots__ = ("name", "schema_version", "tool_version")
    NAME_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_VERSION_FIELD_NUMBER: _ClassVar[int]
    TOOL_VERSION_FIELD_NUMBER: _ClassVar[int]
    name: str
    schema_version: str
    tool_version: str
    def __init__(self, name: _Optional[str] = ..., schema_version: _Optional[str] = ..., tool_version: _Optional[str] = ...) -> None: ...

class SetToolDefaultResponse(_message.Message):
    __slots__ = ("tool",)
    TOOL_FIELD_NUMBER: _ClassVar[int]
    tool: Tool
    def __init__(self, tool: _Optional[_Union[Tool, _Mapping]] = ...) -> None: ...

class UpdateToolRequest(_message.Message):
    __slots__ = ("tool",)
    TOOL_FIELD_NUMBER: _ClassVar[int]
    tool: Tool
    def __init__(self, tool: _Optional[_Union[Tool, _Mapping]] = ...) -> None: ...

class UpdateToolResponse(_message.Message):
    __slots__ = ("tool",)
    TOOL_FIELD_NUMBER: _ClassVar[int]
    tool: Tool
    def __init__(self, tool: _Optional[_Union[Tool, _Mapping]] = ...) -> None: ...

class DeleteToolRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class ListScopedToolsRequest(_message.Message):
    __slots__ = ("identifier", "filter", "page_size", "page_token")
    IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    identifier: str
    filter: ScopedToolFilter
    page_size: int
    page_token: str
    def __init__(self, identifier: _Optional[str] = ..., filter: _Optional[_Union[ScopedToolFilter, _Mapping]] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class ListScopedToolsResponse(_message.Message):
    __slots__ = ("next_page_token", "total_size", "prev_page_token", "tools")
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    PREV_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOOLS_FIELD_NUMBER: _ClassVar[int]
    next_page_token: str
    total_size: int
    prev_page_token: str
    tools: _containers.RepeatedCompositeFieldContainer[ScopedTool]
    def __init__(self, next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ..., prev_page_token: _Optional[str] = ..., tools: _Optional[_Iterable[_Union[ScopedTool, _Mapping]]] = ...) -> None: ...

class ScopedToolFilter(_message.Message):
    __slots__ = ("providers", "tool_names", "connection_names")
    PROVIDERS_FIELD_NUMBER: _ClassVar[int]
    TOOL_NAMES_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_NAMES_FIELD_NUMBER: _ClassVar[int]
    providers: _containers.RepeatedScalarFieldContainer[str]
    tool_names: _containers.RepeatedScalarFieldContainer[str]
    connection_names: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, providers: _Optional[_Iterable[str]] = ..., tool_names: _Optional[_Iterable[str]] = ..., connection_names: _Optional[_Iterable[str]] = ...) -> None: ...
